Fix misspellings in comments and docs.
authorAndy Hill <hillad@gmail.com>
Tue, 4 Jun 2013 22:35:36 +0000 (17:35 -0500)
committerBen Pfaff <blp@nicira.com>
Wed, 5 Jun 2013 04:53:33 +0000 (21:53 -0700)
Flagged with: https://github.com/lyda/misspell-check
Run with: git ls-files | misspellings -f -

Signed-off-by: Andy Hill <hillad@gmail.com>
Signed-off-by: Ben Pfaff <blp@nicira.com>
19 files changed:
AUTHORS
README-lisp
datapath/vport.c
lib/cfm.c
lib/netdev-provider.h
lib/netlink-notifier.c
lib/nx-match.c
lib/odp-util.c
lib/stream-ssl.c
lib/stress.h
lib/unixctl.c
lib/vconn.c
ofproto/netflow.c
ofproto/ofproto-dpif.c
ovsdb/table.c
python/ovs/db/data.py
python/ovs/db/schema.py
xenserver/opt_xensource_libexec_InterfaceReconfigure.py
xenserver/opt_xensource_libexec_interface-reconfigure

diff --git a/AUTHORS b/AUTHORS
index d15173e..c0c5a72 100644 (file)
--- a/AUTHORS
+++ b/AUTHORS
@@ -6,6 +6,7 @@ Alexey I. Froloff       raorn@altlinux.org
 Alex Wang               alexw@nicira.com
 Andrew Evans            aevans@nicira.com
 Andrew Lambeth          wal@nicira.com
+Andy Hill               hillad@gmail.com
 Andy Southgate          andy.southgate@citrix.com
 Andy Zhou               azhou@nicira.com
 Ansis Atteka            aatteka@nicira.com
index e0e1ffd..6057706 100644 (file)
@@ -34,7 +34,7 @@ Unix based VMs), or have the hypervisor do proxy ARP.
 
 On the receiving side, the packet arrives without the original MAC header.
 The LISP tunneling code attaches a header with harcoded source and destination
-MAC addres 02:00:00:00:00:00.  This address has all bits set to 0, except the
+MAC address 02:00:00:00:00:00.  This address has all bits set to 0, except the
 locally administered bit, in order to avoid potential collisions with existing
 allocations.  In order for packets to reach their intended destination, the
 destination MAC address needs to be rewritten.  This can be done using the
index 745ffe4..dcb7616 100644 (file)
@@ -407,7 +407,7 @@ int ovs_vport_send(struct vport *vport, struct sk_buff *skb)
  * @err_type: one of enum vport_err_type types to indicate the error type
  *
  * If using the vport generic stats layer indicate that an error of the given
- * type has occured.
+ * type has occurred.
  */
 void ovs_vport_record_error(struct vport *vport, enum vport_err_type err_type)
 {
index 4d4ebcb..64ad18c 100644 (file)
--- a/lib/cfm.c
+++ b/lib/cfm.c
@@ -92,9 +92,9 @@ struct cfm {
     bool check_tnl_key;    /* Verify the tunnel key of inbound packets? */
     bool extended;         /* Extended mode. */
     bool demand;           /* Demand mode. */
-    bool booted;           /* A full fault interval has occured. */
+    bool booted;           /* A full fault interval has occurred. */
     enum cfm_fault_reason fault;  /* Connectivity fault status. */
-    enum cfm_fault_reason recv_fault;  /* Bit mask of faults occuring on
+    enum cfm_fault_reason recv_fault;  /* Bit mask of faults occurring on
                                           receive. */
     bool opup;             /* Operational State. */
     bool remote_opup;      /* Remote Operational State. */
index 2d43431..137b659 100644 (file)
@@ -470,7 +470,7 @@ struct netdev_class {
      * anyhow. */
     int (*add_router)(struct netdev *netdev, struct in_addr router);
 
-    /* Looks up the next hop for 'host'.  If succesful, stores the next hop
+    /* Looks up the next hop for 'host'.  If successful, stores the next hop
      * gateway's address (0 if 'host' is on a directly connected network) in
      * '*next_hop' and a copy of the name of the device to reach 'host' in
      * '*netdev_name', and returns 0.  The caller is responsible for freeing
index 6739ece..1e1a317 100644 (file)
@@ -41,7 +41,7 @@ struct nln {
 
     /* Passed in by nln_create(). */
     int multicast_group;         /* Multicast group we listen on. */
-    int protocol;                /* Protocal passed to nl_sock_create(). */
+    int protocol;                /* Protocol passed to nl_sock_create(). */
     nln_parse_func *parse;       /* Message parsing function. */
     void *change;                /* Change passed to parse. */
 };
index a91d56b..e111000 100644 (file)
@@ -280,7 +280,7 @@ oxm_pull_match__(struct ofpbuf *b, bool strict, struct match *match)
                        strict, match, NULL, NULL);
 }
 
-/* Parses the oxm formatted match description preceeded by a struct ofp11_match
+/* Parses the oxm formatted match description preceded by a struct ofp11_match
  * in 'b' with length 'match_len'.  Stores the result in 'match'.
  *
  * Fails with an error when encountering unknown OXM headers.
index 1c48e7b..030ad5e 100644 (file)
@@ -1997,7 +1997,7 @@ parse_8021q_onward(const struct nlattr *attrs[OVS_KEY_ATTR_MAX + 1],
     enum odp_key_fitness fitness;
     ovs_be16 tci;
 
-    /* Calulate fitness of outer attributes. */
+    /* Calculate fitness of outer attributes. */
     expected_attrs |= ((UINT64_C(1) << OVS_KEY_ATTR_VLAN) |
                        (UINT64_C(1) << OVS_KEY_ATTR_ENCAP));
     fitness = check_expectations(present_attrs, out_of_range_attr,
@@ -2449,7 +2449,7 @@ commit_odp_actions(const struct flow *flow, struct flow *base,
     commit_vlan_action(flow, base, odp_actions);
     commit_set_nw_action(flow, base, odp_actions);
     commit_set_port_action(flow, base, odp_actions);
-    /* Commiting MPLS actions should occur after committing nw and port
+    /* Committing MPLS actions should occur after committing nw and port
      * actions. This is because committing MPLS actions may alter a packet so
      * that it is no longer IP and thus nw and port actions are no longer valid.
      */
index ddf65a3..5caac49 100644 (file)
@@ -442,7 +442,7 @@ ssl_connect(struct stream *stream)
 
     case STATE_SSL_CONNECTING:
         /* Capture the first few bytes of received data so that we can guess
-         * what kind of funny data we've been sent if SSL negotation fails. */
+         * what kind of funny data we've been sent if SSL negotiation fails. */
         if (sslv->n_head <= 0) {
             sslv->n_head = recv(sslv->fd, sslv->head, sizeof sslv->head,
                                 MSG_PEEK);
index 498deef..8f3d359 100644 (file)
@@ -53,7 +53,7 @@ struct stress_option {
  *
  * DEFAULT is the default value for the option.  Specify 0 to disable the
  * option by default, which should be the usual choice.  But some options can
- * be left on at low levels without noticable impact to the end user.  An
+ * be left on at low levels without noticeable impact to the end user.  An
  * example would be failing to allocate a buffer for every 100000th packet
  * processed by the system.
  */
index 104a2d9..3d5eda6 100644 (file)
@@ -168,7 +168,7 @@ unixctl_command_reply(struct unixctl_conn *conn, const char *result)
 }
 
 /* Replies to the active unixctl connection 'conn'. 'error' is sent to the
- * client indicating an error occured processing the command.  Only one call to
+ * client indicating an error occurred processing the command.  Only one call to
  * unixctl_command_reply() or unixctl_command_reply_error() may be made per
  * request. */
 void
index 71e6d05..dc84cbb 100644 (file)
@@ -754,7 +754,7 @@ vconn_recv_block(struct vconn *vconn, struct ofpbuf **msgp)
     return retval;
 }
 
-/* Waits until a message with a transaction ID matching 'xid' is recived on
+/* Waits until a message with a transaction ID matching 'xid' is received on
  * 'vconn'.  Returns 0 if successful, in which case the reply is stored in
  * '*replyp' for the caller to examine and free.  Otherwise returns a positive
  * errno value, or EOF, and sets '*replyp' to null.
index aec3968..7366986 100644 (file)
@@ -41,8 +41,8 @@ struct netflow {
     uint8_t engine_id;            /* Value of engine_id to use. */
     long long int boot_time;      /* Time when netflow_create() was called. */
     struct collectors *collectors; /* NetFlow collectors. */
-    bool add_id_to_iface;         /* Put the 7 least signficiant bits of
-                                   * 'engine_id' into the most signficant
+    bool add_id_to_iface;         /* Put the 7 least significiant bits of
+                                   * 'engine_id' into the most significant
                                    * bits of the interface fields. */
     uint32_t netflow_cnt;         /* Flow sequence number for NetFlow. */
     struct ofpbuf packet;         /* NetFlow packet being accumulated. */
index 13e2aad..2307577 100644 (file)
@@ -3819,7 +3819,7 @@ handle_flow_miss(struct flow_miss *miss, struct flow_miss_op *ops,
          * flow keys with fitness ODP_FIT_TO_LITTLE.  This breaks a fundamental
          * assumption used throughout the facet and subfacet handling code.
          * Since we have to handle these misses in userspace anyway, we simply
-         * skip facet creation, avoiding the problem alltogether. */
+         * skip facet creation, avoiding the problem altogether. */
         if (miss->key_fitness == ODP_FIT_TOO_LITTLE
             || !flow_miss_should_make_facet(ofproto, miss, hash)) {
             handle_flow_miss_without_facet(miss, ops, n_ops);
index 0d4f522..e7545ad 100644 (file)
@@ -230,7 +230,7 @@ error:
  * The "isRoot" member is included in the JSON only if its value would differ
  * from 'default_is_root'.  Ordinarily 'default_is_root' should be false,
  * because ordinarily a table would be not be part of the root set if its
* "isRoot" member is omitted.  However, garbage collection was not orginally
  * included in OVSDB, so in older schemas that do not include any "isRoot"
  * members, every table is implicitly part of the root set.  To serialize such
  * a schema in a way that can be read by older OVSDB tools, specify
index 55e7a73..e21a1cc 100644 (file)
@@ -468,7 +468,7 @@ class Datum(object):
         new datum's value is taken from 'value', which must take the form
         described as a valid return value from Datum.to_python() for 'type'.
 
-        Each scalar value within 'value' is initally passed through
+        Each scalar value within 'value' is initially passed through
         'row_to_uuid', which should convert objects that represent rows (if
         any) into uuid.UUID objects and return other data unchanged.
 
index 1b5a771..bc86232 100644 (file)
@@ -217,7 +217,7 @@ class TableSchema(object):
         differ from 'default_is_root'.  Ordinarily 'default_is_root' should be
         false, because ordinarily a table would be not be part of the root set
         if its "isRoot" member is omitted.  However, garbage collection was not
-        orginally included in OVSDB, so in older schemas that do not include
+        originally included in OVSDB, so in older schemas that do not include
         any "isRoot" members, every table is implicitly part of the root set.
         To serialize such a schema in a way that can be read by older OVSDB
         tools, specify 'default_is_root' as True.
index 22af3c2..f37e038 100644 (file)
@@ -923,7 +923,7 @@ class Datapath(object):
 
            Should assume any configuration files changed attached in
            the preconfigure stage are applied and bring up the
-           necesary devices to provide the datapath for the
+           necessary devices to provide the datapath for the
            PIF.
 
            Should not bring up the IPdev.
index 72bd5e4..3b5c861 100755 (executable)
@@ -242,7 +242,7 @@ def ipdev_configure_static_routes(interface, oc, f):
           172.18.0.0/16 via 192.168.0.4 dev xenbr1
     """
     if oc.has_key('static-routes'):
-        # The key is present - extract comma seperates entries
+        # The key is present - extract comma separates entries
         lines = oc['static-routes'].split(',')
     else:
         # The key is not present, i.e. there are no static routes
@@ -230,7 +230,7 @@ error:
  * from 'default_is_root'.  Ordinarily 'default_is_root' should be false,
  * because ordinarily a table would be not be part of the root set if its
- * "isRoot" member is omitted.  However, garbage collection was not orginally
+ * "isRoot" member is omitted.  However, garbage collection was not originally
  * included in OVSDB, so in older schemas that do not include any "isRoot"
  * members, every table is implicitly part of the root set.  To serialize such